diff --git a/.gitignore b/.gitignore
index d668b5b1..003b7c6f 100644
--- a/.gitignore
+++ b/.gitignore
@@ -1,11 +1,14 @@
.DS_Store
node_modules
.sapper
+__sapper__
yarn.lock
templates/.*
-assets/*.css
+static/*.css
/mastodon
mastodon.log
-assets/robots.txt
+static/robots.txt
/inline-script-checksum.json
-/assets/inline-script.js.map
+/static/inline-script.js.map
+/templates/.*
+/src/manifest/
diff --git a/README.md b/README.md
index e72481a7..a79744bb 100644
--- a/README.md
+++ b/README.md
@@ -76,6 +76,16 @@ To keep your version of Pinafore up to date, you can use `git` to check out the
git checkout $(git tag -l | sort -Vr | head -n 1)
+### Exporting
+
+You can export Pinafore as a static site. Run:
+
+ npm run export
+
+Static files will be written to `__sapper__/export`.
+Be sure to add the [CSP](https://developer.mozilla.org/en-US/docs/Web/HTTP/CSP) header printed out in the console to
+your server config!
+
## Developing and testing
See [CONTRIBUTING.md](https://github.com/nolanlawson/pinafore/blob/master/CONTRIBUTING.md) for
diff --git a/bin/build-inline-script.js b/bin/build-inline-script.js
index eacb4d1f..547bfd8d 100644
--- a/bin/build-inline-script.js
+++ b/bin/build-inline-script.js
@@ -8,7 +8,7 @@ import { rollup } from 'rollup'
import { terser } from 'rollup-plugin-terser'
import replace from 'rollup-plugin-replace'
import fromPairs from 'lodash-es/fromPairs'
-import { themes } from '../routes/_static/themes'
+import { themes } from '../src/routes/_static/themes'
const readFile = pify(fs.readFile.bind(fs))
const writeFile = pify(fs.writeFile.bind(fs))
@@ -36,22 +36,22 @@ async function main () {
sourcemap: true
})
- let fullCode = `${code}\n//# sourceMappingURL=inline-script.js.map`
+ let fullCode = `${code}\n//# sourceMappingURL=/inline-script.js.map`
let checksum = crypto.createHash('sha256').update(fullCode).digest('base64')
let checksumFilepath = path.join(__dirname, '../inline-script-checksum.json')
await writeFile(checksumFilepath, JSON.stringify({ checksum }), 'utf8')
- let html2xxFilepath = path.join(__dirname, '../templates/2xx.html')
- let html2xxFile = await readFile(html2xxFilepath, 'utf8')
- html2xxFile = html2xxFile.replace(
+ let htmlTemplateFilepath = path.join(__dirname, '../src/template.html')
+ let htmlTemplateFile = await readFile(htmlTemplateFilepath, 'utf8')
+ htmlTemplateFile = htmlTemplateFile.replace(
/[\s\S]+/,
''
)
- await writeFile(html2xxFilepath, html2xxFile, 'utf8')
+ await writeFile(htmlTemplateFilepath, htmlTemplateFile, 'utf8')
- await writeFile(path.resolve(__dirname, '../assets/inline-script.js.map'), map.toString(), 'utf8')
+ await writeFile(path.resolve(__dirname, '../static/inline-script.js.map'), map.toString(), 'utf8')
}
main().catch(err => {
diff --git a/bin/build-sass.js b/bin/build-sass.js
index b5199c8b..dc4177d6 100755
--- a/bin/build-sass.js
+++ b/bin/build-sass.js
@@ -16,10 +16,10 @@ const globalScss = path.join(__dirname, '../scss/global.scss')
const defaultThemeScss = path.join(__dirname, '../scss/themes/_default.scss')
const offlineThemeScss = path.join(__dirname, '../scss/themes/_offline.scss')
const customScrollbarScss = path.join(__dirname, '../scss/custom-scrollbars.scss')
-const html2xxFile = path.join(__dirname, '../templates/2xx.html')
+const htmlTemplateFile = path.join(__dirname, '../src/template.html')
const scssDir = path.join(__dirname, '../scss')
const themesScssDir = path.join(__dirname, '../scss/themes')
-const assetsDir = path.join(__dirname, '../assets')
+const assetsDir = path.join(__dirname, '../static')
function doWatch () {
let start = now()
@@ -44,7 +44,7 @@ async function compileGlobalSass () {
let offlineStyle = (await renderCss(offlineThemeScss))
let scrollbarStyle = (await renderCss(customScrollbarScss))
- let html = await readFile(html2xxFile, 'utf8')
+ let html = await readFile(htmlTemplateFile, 'utf8')
html = html.replace(/[\s\S]+/,
`\n` +
`\n` +
@@ -53,7 +53,7 @@ async function compileGlobalSass () {
``
)
- await writeFile(html2xxFile, html, 'utf8')
+ await writeFile(htmlTemplateFile, html, 'utf8')
}
async function compileThemesSass () {
diff --git a/bin/build-svg.js b/bin/build-svg.js
index 38179787..0d451976 100755
--- a/bin/build-svg.js
+++ b/bin/build-svg.js
@@ -28,13 +28,13 @@ async function main () {
result = ``
- let html2xxFilepath = path.join(__dirname, '../templates/2xx.html')
- let html2xxFile = await readFile(html2xxFilepath, 'utf8')
- html2xxFile = html2xxFile.replace(
+ let htmlTemplateFilepath = path.join(__dirname, '../src/template.html')
+ let htmlTemplateFile = await readFile(htmlTemplateFilepath, 'utf8')
+ htmlTemplateFile = htmlTemplateFile.replace(
/[\s\S]+/,
'' + result + ''
)
- await writeFile(html2xxFilepath, html2xxFile, 'utf8')
+ await writeFile(htmlTemplateFilepath, htmlTemplateFile, 'utf8')
}
main().catch(err => {
diff --git a/bin/deploy.sh b/bin/deploy.sh
index 34b87480..70a64b72 100755
--- a/bin/deploy.sh
+++ b/bin/deploy.sh
@@ -7,9 +7,9 @@ PATH="$PATH:./node_modules/.bin"
# set up robots.txt
if [[ "$DEPLOY_TYPE" == "dev" ]]; then
- printf 'User-agent: *\nDisallow: /' > assets/robots.txt
+ printf 'User-agent: *\nDisallow: /' > static/robots.txt
else
- rm -f assets/robots.txt
+ rm -f static/robots.txt
fi
# if in travis, use the $NOW_TOKEN
diff --git a/bin/print-export-info.js b/bin/print-export-info.js
new file mode 100644
index 00000000..d83eb332
--- /dev/null
+++ b/bin/print-export-info.js
@@ -0,0 +1,48 @@
+const fs = require('fs')
+const path = require('path')
+
+const checksum = require('../inline-script-checksum').checksum
+const html = fs.readFileSync(path.join(__dirname, '../__sapper__/export/index.html'), 'utf8')
+const nonce = html.match(/
diff --git a/routes/accounts/[accountId].html b/routes/accounts/[accountId].html
deleted file mode 100644
index ac63c048..00000000
--- a/routes/accounts/[accountId].html
+++ /dev/null
@@ -1,21 +0,0 @@
-
-
-
-
-
\ No newline at end of file
diff --git a/src/client.js b/src/client.js
new file mode 100644
index 00000000..13bcf127
--- /dev/null
+++ b/src/client.js
@@ -0,0 +1,14 @@
+import * as sapper from '../__sapper__/client.js'
+import { loadPolyfills } from './routes/_utils/loadPolyfills'
+import './routes/_utils/serviceWorkerClient'
+import './routes/_utils/historyEvents'
+import './routes/_utils/loadingMask'
+
+loadPolyfills().then(() => {
+ console.log('init()')
+ sapper.start({ target: document.querySelector('#sapper') })
+})
+
+if (module.hot) {
+ module.hot.accept()
+}
diff --git a/routes/_a11y/getAccessibleLabelForStatus.js b/src/routes/_a11y/getAccessibleLabelForStatus.js
similarity index 100%
rename from routes/_a11y/getAccessibleLabelForStatus.js
rename to src/routes/_a11y/getAccessibleLabelForStatus.js
diff --git a/routes/_a11y/getAccountAccessibleName.js b/src/routes/_a11y/getAccountAccessibleName.js
similarity index 100%
rename from routes/_a11y/getAccountAccessibleName.js
rename to src/routes/_a11y/getAccountAccessibleName.js
diff --git a/routes/_actions/accounts.js b/src/routes/_actions/accounts.js
similarity index 100%
rename from routes/_actions/accounts.js
rename to src/routes/_actions/accounts.js
diff --git a/routes/_actions/addInstance.js b/src/routes/_actions/addInstance.js
similarity index 98%
rename from routes/_actions/addInstance.js
rename to src/routes/_actions/addInstance.js
index ffa24b5a..63c08e14 100644
--- a/routes/_actions/addInstance.js
+++ b/src/routes/_actions/addInstance.js
@@ -1,6 +1,6 @@
import { getAccessTokenFromAuthCode, registerApplication, generateAuthLink } from '../_api/oauth'
import { getInstanceInfo } from '../_api/instance'
-import { goto } from 'sapper/runtime.js'
+import { goto } from '../../../__sapper__/client'
import { switchToTheme } from '../_utils/themeEngine'
import { store } from '../_store/store'
import { updateVerifyCredentialsForInstance } from './instances'
diff --git a/routes/_actions/addStatusOrNotification.js b/src/routes/_actions/addStatusOrNotification.js
similarity index 100%
rename from routes/_actions/addStatusOrNotification.js
rename to src/routes/_actions/addStatusOrNotification.js
diff --git a/routes/_actions/autosuggest.js b/src/routes/_actions/autosuggest.js
similarity index 100%
rename from routes/_actions/autosuggest.js
rename to src/routes/_actions/autosuggest.js
diff --git a/routes/_actions/block.js b/src/routes/_actions/block.js
similarity index 100%
rename from routes/_actions/block.js
rename to src/routes/_actions/block.js
diff --git a/routes/_actions/compose.js b/src/routes/_actions/compose.js
similarity index 100%
rename from routes/_actions/compose.js
rename to src/routes/_actions/compose.js
diff --git a/routes/_actions/contentWarnings.js b/src/routes/_actions/contentWarnings.js
similarity index 100%
rename from routes/_actions/contentWarnings.js
rename to src/routes/_actions/contentWarnings.js
diff --git a/routes/_actions/copyText.js b/src/routes/_actions/copyText.js
similarity index 100%
rename from routes/_actions/copyText.js
rename to src/routes/_actions/copyText.js
diff --git a/routes/_actions/createMakeProps.js b/src/routes/_actions/createMakeProps.js
similarity index 100%
rename from routes/_actions/createMakeProps.js
rename to src/routes/_actions/createMakeProps.js
diff --git a/routes/_actions/delete.js b/src/routes/_actions/delete.js
similarity index 100%
rename from routes/_actions/delete.js
rename to src/routes/_actions/delete.js
diff --git a/routes/_actions/deleteStatuses.js b/src/routes/_actions/deleteStatuses.js
similarity index 100%
rename from routes/_actions/deleteStatuses.js
rename to src/routes/_actions/deleteStatuses.js
diff --git a/routes/_actions/emoji.js b/src/routes/_actions/emoji.js
similarity index 100%
rename from routes/_actions/emoji.js
rename to src/routes/_actions/emoji.js
diff --git a/routes/_actions/favorite.js b/src/routes/_actions/favorite.js
similarity index 100%
rename from routes/_actions/favorite.js
rename to src/routes/_actions/favorite.js
diff --git a/routes/_actions/follow.js b/src/routes/_actions/follow.js
similarity index 100%
rename from routes/_actions/follow.js
rename to src/routes/_actions/follow.js
diff --git a/routes/_actions/followRequests.js b/src/routes/_actions/followRequests.js
similarity index 100%
rename from routes/_actions/followRequests.js
rename to src/routes/_actions/followRequests.js
diff --git a/routes/_actions/instances.js b/src/routes/_actions/instances.js
similarity index 98%
rename from routes/_actions/instances.js
rename to src/routes/_actions/instances.js
index e77f9a52..ad06caf0 100644
--- a/routes/_actions/instances.js
+++ b/src/routes/_actions/instances.js
@@ -2,7 +2,7 @@ import { getVerifyCredentials } from '../_api/user'
import { store } from '../_store/store'
import { switchToTheme } from '../_utils/themeEngine'
import { toast } from '../_utils/toast'
-import { goto } from 'sapper/runtime.js'
+import { goto } from '../../../__sapper__/client'
import { cacheFirstUpdateAfter } from '../_utils/sync'
import { getInstanceInfo } from '../_api/instance'
import { database } from '../_database/database'
diff --git a/routes/_actions/lists.js b/src/routes/_actions/lists.js
similarity index 100%
rename from routes/_actions/lists.js
rename to src/routes/_actions/lists.js
diff --git a/routes/_actions/media.js b/src/routes/_actions/media.js
similarity index 100%
rename from routes/_actions/media.js
rename to src/routes/_actions/media.js
diff --git a/routes/_actions/mute.js b/src/routes/_actions/mute.js
similarity index 100%
rename from routes/_actions/mute.js
rename to src/routes/_actions/mute.js
diff --git a/routes/_actions/muteConversation.js b/src/routes/_actions/muteConversation.js
similarity index 100%
rename from routes/_actions/muteConversation.js
rename to src/routes/_actions/muteConversation.js
diff --git a/routes/_actions/pin.js b/src/routes/_actions/pin.js
similarity index 100%
rename from routes/_actions/pin.js
rename to src/routes/_actions/pin.js
diff --git a/routes/_actions/pinnedStatuses.js b/src/routes/_actions/pinnedStatuses.js
similarity index 100%
rename from routes/_actions/pinnedStatuses.js
rename to src/routes/_actions/pinnedStatuses.js
diff --git a/routes/_actions/postPrivacy.js b/src/routes/_actions/postPrivacy.js
similarity index 100%
rename from routes/_actions/postPrivacy.js
rename to src/routes/_actions/postPrivacy.js
diff --git a/routes/_actions/pushSubscription.js b/src/routes/_actions/pushSubscription.js
similarity index 100%
rename from routes/_actions/pushSubscription.js
rename to src/routes/_actions/pushSubscription.js
diff --git a/routes/_actions/reblog.js b/src/routes/_actions/reblog.js
similarity index 100%
rename from routes/_actions/reblog.js
rename to src/routes/_actions/reblog.js
diff --git a/routes/_actions/requests.js b/src/routes/_actions/requests.js
similarity index 100%
rename from routes/_actions/requests.js
rename to src/routes/_actions/requests.js
diff --git a/routes/_actions/search.js b/src/routes/_actions/search.js
similarity index 100%
rename from routes/_actions/search.js
rename to src/routes/_actions/search.js
diff --git a/routes/_actions/setDomainBlocked.js b/src/routes/_actions/setDomainBlocked.js
similarity index 100%
rename from routes/_actions/setDomainBlocked.js
rename to src/routes/_actions/setDomainBlocked.js
diff --git a/routes/_actions/setShowReblogs.js b/src/routes/_actions/setShowReblogs.js
similarity index 100%
rename from routes/_actions/setShowReblogs.js
rename to src/routes/_actions/setShowReblogs.js
diff --git a/routes/_actions/statuses.js b/src/routes/_actions/statuses.js
similarity index 100%
rename from routes/_actions/statuses.js
rename to src/routes/_actions/statuses.js
diff --git a/routes/_actions/streaming.js b/src/routes/_actions/streaming.js
similarity index 100%
rename from routes/_actions/streaming.js
rename to src/routes/_actions/streaming.js
diff --git a/routes/_actions/timeline.js b/src/routes/_actions/timeline.js
similarity index 100%
rename from routes/_actions/timeline.js
rename to src/routes/_actions/timeline.js
diff --git a/routes/_api/TimelineStream.js b/src/routes/_api/TimelineStream.js
similarity index 100%
rename from routes/_api/TimelineStream.js
rename to src/routes/_api/TimelineStream.js
diff --git a/routes/_api/block.js b/src/routes/_api/block.js
similarity index 100%
rename from routes/_api/block.js
rename to src/routes/_api/block.js
diff --git a/routes/_api/blockDomain.js b/src/routes/_api/blockDomain.js
similarity index 100%
rename from routes/_api/blockDomain.js
rename to src/routes/_api/blockDomain.js
diff --git a/routes/_api/blockedAndMuted.js b/src/routes/_api/blockedAndMuted.js
similarity index 100%
rename from routes/_api/blockedAndMuted.js
rename to src/routes/_api/blockedAndMuted.js
diff --git a/routes/_api/delete.js b/src/routes/_api/delete.js
similarity index 100%
rename from routes/_api/delete.js
rename to src/routes/_api/delete.js
diff --git a/routes/_api/emoji.js b/src/routes/_api/emoji.js
similarity index 100%
rename from routes/_api/emoji.js
rename to src/routes/_api/emoji.js
diff --git a/routes/_api/favorite.js b/src/routes/_api/favorite.js
similarity index 100%
rename from routes/_api/favorite.js
rename to src/routes/_api/favorite.js
diff --git a/routes/_api/follow.js b/src/routes/_api/follow.js
similarity index 100%
rename from routes/_api/follow.js
rename to src/routes/_api/follow.js
diff --git a/routes/_api/followsAndFollowers.js b/src/routes/_api/followsAndFollowers.js
similarity index 100%
rename from routes/_api/followsAndFollowers.js
rename to src/routes/_api/followsAndFollowers.js
diff --git a/routes/_api/instance.js b/src/routes/_api/instance.js
similarity index 100%
rename from routes/_api/instance.js
rename to src/routes/_api/instance.js
diff --git a/routes/_api/lists.js b/src/routes/_api/lists.js
similarity index 100%
rename from routes/_api/lists.js
rename to src/routes/_api/lists.js
diff --git a/routes/_api/media.js b/src/routes/_api/media.js
similarity index 100%
rename from routes/_api/media.js
rename to src/routes/_api/media.js
diff --git a/routes/_api/mute.js b/src/routes/_api/mute.js
similarity index 100%
rename from routes/_api/mute.js
rename to src/routes/_api/mute.js
diff --git a/routes/_api/muteConversation.js b/src/routes/_api/muteConversation.js
similarity index 100%
rename from routes/_api/muteConversation.js
rename to src/routes/_api/muteConversation.js
diff --git a/routes/_api/oauth.js b/src/routes/_api/oauth.js
similarity index 100%
rename from routes/_api/oauth.js
rename to src/routes/_api/oauth.js
diff --git a/routes/_api/pin.js b/src/routes/_api/pin.js
similarity index 100%
rename from routes/_api/pin.js
rename to src/routes/_api/pin.js
diff --git a/routes/_api/pinnedStatuses.js b/src/routes/_api/pinnedStatuses.js
similarity index 100%
rename from routes/_api/pinnedStatuses.js
rename to src/routes/_api/pinnedStatuses.js
diff --git a/routes/_api/pushSubscription.js b/src/routes/_api/pushSubscription.js
similarity index 100%
rename from routes/_api/pushSubscription.js
rename to src/routes/_api/pushSubscription.js
diff --git a/routes/_api/reblog.js b/src/routes/_api/reblog.js
similarity index 100%
rename from routes/_api/reblog.js
rename to src/routes/_api/reblog.js
diff --git a/routes/_api/reblogsAndFavs.js b/src/routes/_api/reblogsAndFavs.js
similarity index 100%
rename from routes/_api/reblogsAndFavs.js
rename to src/routes/_api/reblogsAndFavs.js
diff --git a/routes/_api/relationships.js b/src/routes/_api/relationships.js
similarity index 100%
rename from routes/_api/relationships.js
rename to src/routes/_api/relationships.js
diff --git a/routes/_api/requests.js b/src/routes/_api/requests.js
similarity index 100%
rename from routes/_api/requests.js
rename to src/routes/_api/requests.js
diff --git a/routes/_api/search.js b/src/routes/_api/search.js
similarity index 100%
rename from routes/_api/search.js
rename to src/routes/_api/search.js
diff --git a/routes/_api/showReblogs.js b/src/routes/_api/showReblogs.js
similarity index 100%
rename from routes/_api/showReblogs.js
rename to src/routes/_api/showReblogs.js
diff --git a/routes/_api/statuses.js b/src/routes/_api/statuses.js
similarity index 100%
rename from routes/_api/statuses.js
rename to src/routes/_api/statuses.js
diff --git a/routes/_api/timelines.js b/src/routes/_api/timelines.js
similarity index 100%
rename from routes/_api/timelines.js
rename to src/routes/_api/timelines.js
diff --git a/routes/_api/updateCredentials.js b/src/routes/_api/updateCredentials.js
similarity index 100%
rename from routes/_api/updateCredentials.js
rename to src/routes/_api/updateCredentials.js
diff --git a/routes/_api/user.js b/src/routes/_api/user.js
similarity index 100%
rename from routes/_api/user.js
rename to src/routes/_api/user.js
diff --git a/routes/_api/utils.js b/src/routes/_api/utils.js
similarity index 100%
rename from routes/_api/utils.js
rename to src/routes/_api/utils.js
diff --git a/routes/_components/AccountsListPage.html b/src/routes/_components/AccountsListPage.html
similarity index 91%
rename from routes/_components/AccountsListPage.html
rename to src/routes/_components/AccountsListPage.html
index 1549a85a..38883f44 100644
--- a/routes/_components/AccountsListPage.html
+++ b/src/routes/_components/AccountsListPage.html
@@ -32,8 +32,8 @@
\ No newline at end of file
+
diff --git a/routes/_components/AutoplayVideo.html b/src/routes/_components/AutoplayVideo.html
similarity index 100%
rename from routes/_components/AutoplayVideo.html
rename to src/routes/_components/AutoplayVideo.html
diff --git a/routes/_components/Avatar.html b/src/routes/_components/Avatar.html
similarity index 100%
rename from routes/_components/Avatar.html
rename to src/routes/_components/Avatar.html
diff --git a/routes/_components/DynamicPageBanner.html b/src/routes/_components/DynamicPageBanner.html
similarity index 100%
rename from routes/_components/DynamicPageBanner.html
rename to src/routes/_components/DynamicPageBanner.html
diff --git a/routes/_components/ExternalLink.html b/src/routes/_components/ExternalLink.html
similarity index 100%
rename from routes/_components/ExternalLink.html
rename to src/routes/_components/ExternalLink.html
diff --git a/routes/_components/FreeTextLayout.html b/src/routes/_components/FreeTextLayout.html
similarity index 100%
rename from routes/_components/FreeTextLayout.html
rename to src/routes/_components/FreeTextLayout.html
diff --git a/routes/_components/HiddenFromSSR.html b/src/routes/_components/HiddenFromSSR.html
similarity index 53%
rename from routes/_components/HiddenFromSSR.html
rename to src/routes/_components/HiddenFromSSR.html
index 7a3fd1d2..0fa29a79 100644
--- a/routes/_components/HiddenFromSSR.html
+++ b/src/routes/_components/HiddenFromSSR.html
@@ -1,4 +1,4 @@
-
+
@@ -6,4 +6,4 @@
.hidden-from-ssr {
opacity: 0;
}
-
\ No newline at end of file
+
diff --git a/routes/_components/IconButton.html b/src/routes/_components/IconButton.html
similarity index 100%
rename from routes/_components/IconButton.html
rename to src/routes/_components/IconButton.html
diff --git a/routes/_components/InformationalFooter.html b/src/routes/_components/InformationalFooter.html
similarity index 100%
rename from routes/_components/InformationalFooter.html
rename to src/routes/_components/InformationalFooter.html
diff --git a/routes/_components/Label.html b/src/routes/_components/Label.html
similarity index 100%
rename from routes/_components/Label.html
rename to src/routes/_components/Label.html
diff --git a/routes/_components/LazyImage.html b/src/routes/_components/LazyImage.html
similarity index 100%
rename from routes/_components/LazyImage.html
rename to src/routes/_components/LazyImage.html
diff --git a/routes/_components/LazyPage.html b/src/routes/_components/LazyPage.html
similarity index 68%
rename from routes/_components/LazyPage.html
rename to src/routes/_components/LazyPage.html
index 09c0e5ea..e1cd95db 100644
--- a/routes/_components/LazyPage.html
+++ b/src/routes/_components/LazyPage.html
@@ -2,6 +2,7 @@
{/if}
\ No newline at end of file
+
diff --git a/routes/_components/LoadingMask.html b/src/routes/_components/LoadingMask.html
similarity index 100%
rename from routes/_components/LoadingMask.html
rename to src/routes/_components/LoadingMask.html
diff --git a/routes/_components/LoadingPage.html b/src/routes/_components/LoadingPage.html
similarity index 100%
rename from routes/_components/LoadingPage.html
rename to src/routes/_components/LoadingPage.html
diff --git a/routes/_components/LoadingSpinner.html b/src/routes/_components/LoadingSpinner.html
similarity index 100%
rename from routes/_components/LoadingSpinner.html
rename to src/routes/_components/LoadingSpinner.html
diff --git a/routes/_components/Nav.html b/src/routes/_components/Nav.html
similarity index 100%
rename from routes/_components/Nav.html
rename to src/routes/_components/Nav.html
diff --git a/routes/_components/NavItem.html b/src/routes/_components/NavItem.html
similarity index 100%
rename from routes/_components/NavItem.html
rename to src/routes/_components/NavItem.html
diff --git a/routes/_components/NonAutoplayGifv.html b/src/routes/_components/NonAutoplayGifv.html
similarity index 100%
rename from routes/_components/NonAutoplayGifv.html
rename to src/routes/_components/NonAutoplayGifv.html
diff --git a/routes/_components/NonAutoplayImg.html b/src/routes/_components/NonAutoplayImg.html
similarity index 100%
rename from routes/_components/NonAutoplayImg.html
rename to src/routes/_components/NonAutoplayImg.html
diff --git a/routes/_components/NotLoggedInHome.html b/src/routes/_components/NotLoggedInHome.html
similarity index 100%
rename from routes/_components/NotLoggedInHome.html
rename to src/routes/_components/NotLoggedInHome.html
diff --git a/routes/_components/PlayVideoIcon.html b/src/routes/_components/PlayVideoIcon.html
similarity index 100%
rename from routes/_components/PlayVideoIcon.html
rename to src/routes/_components/PlayVideoIcon.html
diff --git a/routes/_components/TimelineHomePage.html b/src/routes/_components/TimelineHomePage.html
similarity index 84%
rename from routes/_components/TimelineHomePage.html
rename to src/routes/_components/TimelineHomePage.html
index 5a2de4bd..ef233959 100644
--- a/routes/_components/TimelineHomePage.html
+++ b/src/routes/_components/TimelineHomePage.html
@@ -28,10 +28,10 @@
}
\ No newline at end of file
+
diff --git a/routes/_components/TimelinePage.html b/src/routes/_components/TimelinePage.html
similarity index 85%
rename from routes/_components/TimelinePage.html
rename to src/routes/_components/TimelinePage.html
index 0f4ae1a3..50cbe874 100644
--- a/routes/_components/TimelinePage.html
+++ b/src/routes/_components/TimelinePage.html
@@ -23,9 +23,9 @@
}
\ No newline at end of file
+
diff --git a/routes/_components/Title.html b/src/routes/_components/Title.html
similarity index 100%
rename from routes/_components/Title.html
rename to src/routes/_components/Title.html
diff --git a/routes/_components/Toast.html b/src/routes/_components/Toast.html
similarity index 100%
rename from routes/_components/Toast.html
rename to src/routes/_components/Toast.html
diff --git a/routes/_components/community/PageList.html b/src/routes/_components/community/PageList.html
similarity index 100%
rename from routes/_components/community/PageList.html
rename to src/routes/_components/community/PageList.html
diff --git a/routes/_components/community/PageListItem.html b/src/routes/_components/community/PageListItem.html
similarity index 97%
rename from routes/_components/community/PageListItem.html
rename to src/routes/_components/community/PageListItem.html
index adc99879..5fd22ddc 100644
--- a/routes/_components/community/PageListItem.html
+++ b/src/routes/_components/community/PageListItem.html
@@ -65,7 +65,7 @@
\ No newline at end of file
+
diff --git a/routes/_components/compose/ComposeAuthor.html b/src/routes/_components/compose/ComposeAuthor.html
similarity index 100%
rename from routes/_components/compose/ComposeAuthor.html
rename to src/routes/_components/compose/ComposeAuthor.html
diff --git a/routes/_components/compose/ComposeAutosuggest.html b/src/routes/_components/compose/ComposeAutosuggest.html
similarity index 100%
rename from routes/_components/compose/ComposeAutosuggest.html
rename to src/routes/_components/compose/ComposeAutosuggest.html
diff --git a/routes/_components/compose/ComposeAutosuggestionList.html b/src/routes/_components/compose/ComposeAutosuggestionList.html
similarity index 100%
rename from routes/_components/compose/ComposeAutosuggestionList.html
rename to src/routes/_components/compose/ComposeAutosuggestionList.html
diff --git a/routes/_components/compose/ComposeBox.html b/src/routes/_components/compose/ComposeBox.html
similarity index 100%
rename from routes/_components/compose/ComposeBox.html
rename to src/routes/_components/compose/ComposeBox.html
diff --git a/routes/_components/compose/ComposeButton.html b/src/routes/_components/compose/ComposeButton.html
similarity index 100%
rename from routes/_components/compose/ComposeButton.html
rename to src/routes/_components/compose/ComposeButton.html
diff --git a/routes/_components/compose/ComposeContentWarning.html b/src/routes/_components/compose/ComposeContentWarning.html
similarity index 100%
rename from routes/_components/compose/ComposeContentWarning.html
rename to src/routes/_components/compose/ComposeContentWarning.html
diff --git a/routes/_components/compose/ComposeInput.html b/src/routes/_components/compose/ComposeInput.html
similarity index 100%
rename from routes/_components/compose/ComposeInput.html
rename to src/routes/_components/compose/ComposeInput.html
diff --git a/routes/_components/compose/ComposeLengthGauge.html b/src/routes/_components/compose/ComposeLengthGauge.html
similarity index 100%
rename from routes/_components/compose/ComposeLengthGauge.html
rename to src/routes/_components/compose/ComposeLengthGauge.html
diff --git a/routes/_components/compose/ComposeLengthIndicator.html b/src/routes/_components/compose/ComposeLengthIndicator.html
similarity index 100%
rename from routes/_components/compose/ComposeLengthIndicator.html
rename to src/routes/_components/compose/ComposeLengthIndicator.html
diff --git a/routes/_components/compose/ComposeMedia.html b/src/routes/_components/compose/ComposeMedia.html
similarity index 100%
rename from routes/_components/compose/ComposeMedia.html
rename to src/routes/_components/compose/ComposeMedia.html
diff --git a/routes/_components/compose/ComposeMediaItem.html b/src/routes/_components/compose/ComposeMediaItem.html
similarity index 100%
rename from routes/_components/compose/ComposeMediaItem.html
rename to src/routes/_components/compose/ComposeMediaItem.html
diff --git a/routes/_components/compose/ComposeStickyButton.html b/src/routes/_components/compose/ComposeStickyButton.html
similarity index 100%
rename from routes/_components/compose/ComposeStickyButton.html
rename to src/routes/_components/compose/ComposeStickyButton.html
diff --git a/routes/_components/compose/ComposeToolbar.html b/src/routes/_components/compose/ComposeToolbar.html
similarity index 100%
rename from routes/_components/compose/ComposeToolbar.html
rename to src/routes/_components/compose/ComposeToolbar.html
diff --git a/routes/_components/dialog/asyncDialogs.js b/src/routes/_components/dialog/asyncDialogs.js
similarity index 100%
rename from routes/_components/dialog/asyncDialogs.js
rename to src/routes/_components/dialog/asyncDialogs.js
diff --git a/routes/_components/dialog/components/AccountProfileOptionsDialog.html b/src/routes/_components/dialog/components/AccountProfileOptionsDialog.html
similarity index 100%
rename from routes/_components/dialog/components/AccountProfileOptionsDialog.html
rename to src/routes/_components/dialog/components/AccountProfileOptionsDialog.html
diff --git a/routes/_components/dialog/components/ComposeDialog.html b/src/routes/_components/dialog/components/ComposeDialog.html
similarity index 100%
rename from routes/_components/dialog/components/ComposeDialog.html
rename to src/routes/_components/dialog/components/ComposeDialog.html
diff --git a/routes/_components/dialog/components/ConfirmationDialog.html b/src/routes/_components/dialog/components/ConfirmationDialog.html
similarity index 100%
rename from routes/_components/dialog/components/ConfirmationDialog.html
rename to src/routes/_components/dialog/components/ConfirmationDialog.html
diff --git a/routes/_components/dialog/components/CopyDialog.html b/src/routes/_components/dialog/components/CopyDialog.html
similarity index 100%
rename from routes/_components/dialog/components/CopyDialog.html
rename to src/routes/_components/dialog/components/CopyDialog.html
diff --git a/routes/_components/dialog/components/EmojiDialog.html b/src/routes/_components/dialog/components/EmojiDialog.html
similarity index 100%
rename from routes/_components/dialog/components/EmojiDialog.html
rename to src/routes/_components/dialog/components/EmojiDialog.html
diff --git a/routes/_components/dialog/components/GenericDialogList.html b/src/routes/_components/dialog/components/GenericDialogList.html
similarity index 100%
rename from routes/_components/dialog/components/GenericDialogList.html
rename to src/routes/_components/dialog/components/GenericDialogList.html
diff --git a/routes/_components/dialog/components/ImageDialog.html b/src/routes/_components/dialog/components/ImageDialog.html
similarity index 100%
rename from routes/_components/dialog/components/ImageDialog.html
rename to src/routes/_components/dialog/components/ImageDialog.html
diff --git a/routes/_components/dialog/components/ModalDialog.html b/src/routes/_components/dialog/components/ModalDialog.html
similarity index 100%
rename from routes/_components/dialog/components/ModalDialog.html
rename to src/routes/_components/dialog/components/ModalDialog.html
diff --git a/routes/_components/dialog/components/PostPrivacyDialog.html b/src/routes/_components/dialog/components/PostPrivacyDialog.html
similarity index 100%
rename from routes/_components/dialog/components/PostPrivacyDialog.html
rename to src/routes/_components/dialog/components/PostPrivacyDialog.html
diff --git a/routes/_components/dialog/components/StatusOptionsDialog.html b/src/routes/_components/dialog/components/StatusOptionsDialog.html
similarity index 100%
rename from routes/_components/dialog/components/StatusOptionsDialog.html
rename to src/routes/_components/dialog/components/StatusOptionsDialog.html
diff --git a/routes/_components/dialog/components/VideoDialog.html b/src/routes/_components/dialog/components/VideoDialog.html
similarity index 100%
rename from routes/_components/dialog/components/VideoDialog.html
rename to src/routes/_components/dialog/components/VideoDialog.html
diff --git a/routes/_components/dialog/creators/showAccountProfileOptionsDialog.js b/src/routes/_components/dialog/creators/showAccountProfileOptionsDialog.js
similarity index 100%
rename from routes/_components/dialog/creators/showAccountProfileOptionsDialog.js
rename to src/routes/_components/dialog/creators/showAccountProfileOptionsDialog.js
diff --git a/routes/_components/dialog/creators/showComposeDialog.js b/src/routes/_components/dialog/creators/showComposeDialog.js
similarity index 100%
rename from routes/_components/dialog/creators/showComposeDialog.js
rename to src/routes/_components/dialog/creators/showComposeDialog.js
diff --git a/routes/_components/dialog/creators/showConfirmationDialog.js b/src/routes/_components/dialog/creators/showConfirmationDialog.js
similarity index 100%
rename from routes/_components/dialog/creators/showConfirmationDialog.js
rename to src/routes/_components/dialog/creators/showConfirmationDialog.js
diff --git a/routes/_components/dialog/creators/showCopyDialog.js b/src/routes/_components/dialog/creators/showCopyDialog.js
similarity index 100%
rename from routes/_components/dialog/creators/showCopyDialog.js
rename to src/routes/_components/dialog/creators/showCopyDialog.js
diff --git a/routes/_components/dialog/creators/showEmojiDialog.js b/src/routes/_components/dialog/creators/showEmojiDialog.js
similarity index 100%
rename from routes/_components/dialog/creators/showEmojiDialog.js
rename to src/routes/_components/dialog/creators/showEmojiDialog.js
diff --git a/routes/_components/dialog/creators/showImageDialog.js b/src/routes/_components/dialog/creators/showImageDialog.js
similarity index 100%
rename from routes/_components/dialog/creators/showImageDialog.js
rename to src/routes/_components/dialog/creators/showImageDialog.js
diff --git a/routes/_components/dialog/creators/showPostPrivacyDialog.js b/src/routes/_components/dialog/creators/showPostPrivacyDialog.js
similarity index 100%
rename from routes/_components/dialog/creators/showPostPrivacyDialog.js
rename to src/routes/_components/dialog/creators/showPostPrivacyDialog.js
diff --git a/routes/_components/dialog/creators/showStatusOptionsDialog.js b/src/routes/_components/dialog/creators/showStatusOptionsDialog.js
similarity index 100%
rename from routes/_components/dialog/creators/showStatusOptionsDialog.js
rename to src/routes/_components/dialog/creators/showStatusOptionsDialog.js
diff --git a/routes/_components/dialog/creators/showVideoDialog.js b/src/routes/_components/dialog/creators/showVideoDialog.js
similarity index 100%
rename from routes/_components/dialog/creators/showVideoDialog.js
rename to src/routes/_components/dialog/creators/showVideoDialog.js
diff --git a/routes/_components/dialog/helpers/closeDialog.js b/src/routes/_components/dialog/helpers/closeDialog.js
similarity index 100%
rename from routes/_components/dialog/helpers/closeDialog.js
rename to src/routes/_components/dialog/helpers/closeDialog.js
diff --git a/routes/_components/dialog/helpers/createDialogElement.js b/src/routes/_components/dialog/helpers/createDialogElement.js
similarity index 100%
rename from routes/_components/dialog/helpers/createDialogElement.js
rename to src/routes/_components/dialog/helpers/createDialogElement.js
diff --git a/routes/_components/dialog/helpers/createDialogId.js b/src/routes/_components/dialog/helpers/createDialogId.js
similarity index 100%
rename from routes/_components/dialog/helpers/createDialogId.js
rename to src/routes/_components/dialog/helpers/createDialogId.js
diff --git a/routes/_components/dialog/helpers/onCreateDialog.js b/src/routes/_components/dialog/helpers/onCreateDialog.js
similarity index 100%
rename from routes/_components/dialog/helpers/onCreateDialog.js
rename to src/routes/_components/dialog/helpers/onCreateDialog.js
diff --git a/routes/_components/dialog/helpers/showDialog.js b/src/routes/_components/dialog/helpers/showDialog.js
similarity index 100%
rename from routes/_components/dialog/helpers/showDialog.js
rename to src/routes/_components/dialog/helpers/showDialog.js
diff --git a/routes/_components/list/List.html b/src/routes/_components/list/List.html
similarity index 100%
rename from routes/_components/list/List.html
rename to src/routes/_components/list/List.html
diff --git a/routes/_components/list/ListItem.html b/src/routes/_components/list/ListItem.html
similarity index 100%
rename from routes/_components/list/ListItem.html
rename to src/routes/_components/list/ListItem.html
diff --git a/routes/_components/list/ListLazyItem.html b/src/routes/_components/list/ListLazyItem.html
similarity index 100%
rename from routes/_components/list/ListLazyItem.html
rename to src/routes/_components/list/ListLazyItem.html
diff --git a/routes/_components/list/listStore.js b/src/routes/_components/list/listStore.js
similarity index 100%
rename from routes/_components/list/listStore.js
rename to src/routes/_components/list/listStore.js
diff --git a/routes/_components/profile/AccountDisplayName.html b/src/routes/_components/profile/AccountDisplayName.html
similarity index 100%
rename from routes/_components/profile/AccountDisplayName.html
rename to src/routes/_components/profile/AccountDisplayName.html
diff --git a/routes/_components/profile/AccountProfile.html b/src/routes/_components/profile/AccountProfile.html
similarity index 100%
rename from routes/_components/profile/AccountProfile.html
rename to src/routes/_components/profile/AccountProfile.html
diff --git a/routes/_components/profile/AccountProfileDetails.html b/src/routes/_components/profile/AccountProfileDetails.html
similarity index 100%
rename from routes/_components/profile/AccountProfileDetails.html
rename to src/routes/_components/profile/AccountProfileDetails.html
diff --git a/routes/_components/profile/AccountProfileFollow.html b/src/routes/_components/profile/AccountProfileFollow.html
similarity index 100%
rename from routes/_components/profile/AccountProfileFollow.html
rename to src/routes/_components/profile/AccountProfileFollow.html
diff --git a/routes/_components/profile/AccountProfileHeader.html b/src/routes/_components/profile/AccountProfileHeader.html
similarity index 97%
rename from routes/_components/profile/AccountProfileHeader.html
rename to src/routes/_components/profile/AccountProfileHeader.html
index 06189c22..ffaf75bd 100644
--- a/routes/_components/profile/AccountProfileHeader.html
+++ b/src/routes/_components/profile/AccountProfileHeader.html
@@ -100,7 +100,7 @@
\ No newline at end of file
+
diff --git a/routes/_components/profile/AccountProfileMeta.html b/src/routes/_components/profile/AccountProfileMeta.html
similarity index 100%
rename from routes/_components/profile/AccountProfileMeta.html
rename to src/routes/_components/profile/AccountProfileMeta.html
diff --git a/routes/_components/profile/AccountProfileNote.html b/src/routes/_components/profile/AccountProfileNote.html
similarity index 100%
rename from routes/_components/profile/AccountProfileNote.html
rename to src/routes/_components/profile/AccountProfileNote.html
diff --git a/routes/_components/search/AccountSearchResult.html b/src/routes/_components/search/AccountSearchResult.html
similarity index 100%
rename from routes/_components/search/AccountSearchResult.html
rename to src/routes/_components/search/AccountSearchResult.html
diff --git a/routes/_components/search/HashtagSearchResult.html b/src/routes/_components/search/HashtagSearchResult.html
similarity index 100%
rename from routes/_components/search/HashtagSearchResult.html
rename to src/routes/_components/search/HashtagSearchResult.html
diff --git a/routes/_components/search/Search.html b/src/routes/_components/search/Search.html
similarity index 100%
rename from routes/_components/search/Search.html
rename to src/routes/_components/search/Search.html
diff --git a/routes/_components/search/SearchResult.html b/src/routes/_components/search/SearchResult.html
similarity index 100%
rename from routes/_components/search/SearchResult.html
rename to src/routes/_components/search/SearchResult.html
diff --git a/routes/_components/search/SearchResults.html b/src/routes/_components/search/SearchResults.html
similarity index 100%
rename from routes/_components/search/SearchResults.html
rename to src/routes/_components/search/SearchResults.html
diff --git a/routes/_components/search/StatusSearchResult.html b/src/routes/_components/search/StatusSearchResult.html
similarity index 100%
rename from routes/_components/search/StatusSearchResult.html
rename to src/routes/_components/search/StatusSearchResult.html
diff --git a/routes/_components/settings/SettingsLayout.html b/src/routes/_components/settings/SettingsLayout.html
similarity index 87%
rename from routes/_components/settings/SettingsLayout.html
rename to src/routes/_components/settings/SettingsLayout.html
index 65dfbdd7..c42fc1f3 100644
--- a/routes/_components/settings/SettingsLayout.html
+++ b/src/routes/_components/settings/SettingsLayout.html
@@ -23,7 +23,7 @@
\ No newline at end of file
+
diff --git a/routes/_components/settings/SettingsList.html b/src/routes/_components/settings/SettingsList.html
similarity index 100%
rename from routes/_components/settings/SettingsList.html
rename to src/routes/_components/settings/SettingsList.html
diff --git a/routes/_components/settings/SettingsListItem.html b/src/routes/_components/settings/SettingsListItem.html
similarity index 100%
rename from routes/_components/settings/SettingsListItem.html
rename to src/routes/_components/settings/SettingsListItem.html
diff --git a/routes/_components/settings/SettingsNav.html b/src/routes/_components/settings/SettingsNav.html
similarity index 100%
rename from routes/_components/settings/SettingsNav.html
rename to src/routes/_components/settings/SettingsNav.html
diff --git a/routes/_components/settings/SettingsNavItem.html b/src/routes/_components/settings/SettingsNavItem.html
similarity index 100%
rename from routes/_components/settings/SettingsNavItem.html
rename to src/routes/_components/settings/SettingsNavItem.html
diff --git a/routes/_components/settings/instance/InstanceActions.html b/src/routes/_components/settings/instance/InstanceActions.html
similarity index 92%
rename from routes/_components/settings/instance/InstanceActions.html
rename to src/routes/_components/settings/instance/InstanceActions.html
index 41d4441c..d105e33c 100644
--- a/routes/_components/settings/instance/InstanceActions.html
+++ b/src/routes/_components/settings/instance/InstanceActions.html
@@ -21,7 +21,7 @@
\ No newline at end of file
+
diff --git a/routes/_components/settings/instance/InstanceUserProfile.html b/src/routes/_components/settings/instance/InstanceUserProfile.html
similarity index 82%
rename from routes/_components/settings/instance/InstanceUserProfile.html
rename to src/routes/_components/settings/instance/InstanceUserProfile.html
index 5756d752..2b963325 100644
--- a/routes/_components/settings/instance/InstanceUserProfile.html
+++ b/src/routes/_components/settings/instance/InstanceUserProfile.html
@@ -37,9 +37,9 @@
}
\ No newline at end of file
+
diff --git a/routes/_components/settings/instance/PushNotificationSettings.html b/src/routes/_components/settings/instance/PushNotificationSettings.html
similarity index 100%
rename from routes/_components/settings/instance/PushNotificationSettings.html
rename to src/routes/_components/settings/instance/PushNotificationSettings.html
diff --git a/routes/_components/settings/instance/ThemeSettings.html b/src/routes/_components/settings/instance/ThemeSettings.html
similarity index 100%
rename from routes/_components/settings/instance/ThemeSettings.html
rename to src/routes/_components/settings/instance/ThemeSettings.html
diff --git a/routes/_components/status/Media.html b/src/routes/_components/status/Media.html
similarity index 100%
rename from routes/_components/status/Media.html
rename to src/routes/_components/status/Media.html
diff --git a/routes/_components/status/MediaAttachments.html b/src/routes/_components/status/MediaAttachments.html
similarity index 100%
rename from routes/_components/status/MediaAttachments.html
rename to src/routes/_components/status/MediaAttachments.html
diff --git a/routes/_components/status/Notification.html b/src/routes/_components/status/Notification.html
similarity index 100%
rename from routes/_components/status/Notification.html
rename to src/routes/_components/status/Notification.html
diff --git a/routes/_components/status/Status.html b/src/routes/_components/status/Status.html
similarity index 99%
rename from routes/_components/status/Status.html
rename to src/routes/_components/status/Status.html
index 07c20546..6d26c806 100644
--- a/routes/_components/status/Status.html
+++ b/src/routes/_components/status/Status.html
@@ -107,7 +107,7 @@
import StatusComposeBox from './StatusComposeBox.html'
import StatusMentions from './StatusMentions.html'
import { store } from '../../_store/store'
- import { goto } from 'sapper/runtime.js'
+ import { goto } from '../../../../__sapper__/client'
import { registerClickDelegate } from '../../_utils/delegate'
import { classname } from '../../_utils/classname'
import { checkDomAncestors } from '../../_utils/checkDomAncestors'
diff --git a/routes/_components/status/StatusAuthorHandle.html b/src/routes/_components/status/StatusAuthorHandle.html
similarity index 100%
rename from routes/_components/status/StatusAuthorHandle.html
rename to src/routes/_components/status/StatusAuthorHandle.html
diff --git a/routes/_components/status/StatusAuthorName.html b/src/routes/_components/status/StatusAuthorName.html
similarity index 100%
rename from routes/_components/status/StatusAuthorName.html
rename to src/routes/_components/status/StatusAuthorName.html
diff --git a/routes/_components/status/StatusComposeBox.html b/src/routes/_components/status/StatusComposeBox.html
similarity index 96%
rename from routes/_components/status/StatusComposeBox.html
rename to src/routes/_components/status/StatusComposeBox.html
index 0bbff11b..8555793a 100644
--- a/routes/_components/status/StatusComposeBox.html
+++ b/src/routes/_components/status/StatusComposeBox.html
@@ -15,7 +15,7 @@
}
\ No newline at end of file
+
diff --git a/routes/_components/status/StatusContent.html b/src/routes/_components/status/StatusContent.html
similarity index 100%
rename from routes/_components/status/StatusContent.html
rename to src/routes/_components/status/StatusContent.html
diff --git a/routes/_components/status/StatusDetails.html b/src/routes/_components/status/StatusDetails.html
similarity index 100%
rename from routes/_components/status/StatusDetails.html
rename to src/routes/_components/status/StatusDetails.html
diff --git a/routes/_components/status/StatusHeader.html b/src/routes/_components/status/StatusHeader.html
similarity index 100%
rename from routes/_components/status/StatusHeader.html
rename to src/routes/_components/status/StatusHeader.html
diff --git a/routes/_components/status/StatusMediaAttachments.html b/src/routes/_components/status/StatusMediaAttachments.html
similarity index 100%
rename from routes/_components/status/StatusMediaAttachments.html
rename to src/routes/_components/status/StatusMediaAttachments.html
diff --git a/routes/_components/status/StatusMentions.html b/src/routes/_components/status/StatusMentions.html
similarity index 100%
rename from routes/_components/status/StatusMentions.html
rename to src/routes/_components/status/StatusMentions.html
diff --git a/routes/_components/status/StatusRelativeDate.html b/src/routes/_components/status/StatusRelativeDate.html
similarity index 100%
rename from routes/_components/status/StatusRelativeDate.html
rename to src/routes/_components/status/StatusRelativeDate.html
diff --git a/routes/_components/status/StatusSidebar.html b/src/routes/_components/status/StatusSidebar.html
similarity index 100%
rename from routes/_components/status/StatusSidebar.html
rename to src/routes/_components/status/StatusSidebar.html
diff --git a/routes/_components/status/StatusSpoiler.html b/src/routes/_components/status/StatusSpoiler.html
similarity index 100%
rename from routes/_components/status/StatusSpoiler.html
rename to src/routes/_components/status/StatusSpoiler.html
diff --git a/routes/_components/status/StatusToolbar.html b/src/routes/_components/status/StatusToolbar.html
similarity index 100%
rename from routes/_components/status/StatusToolbar.html
rename to src/routes/_components/status/StatusToolbar.html
diff --git a/routes/_components/timeline/LazyTimeline.html b/src/routes/_components/timeline/LazyTimeline.html
similarity index 100%
rename from routes/_components/timeline/LazyTimeline.html
rename to src/routes/_components/timeline/LazyTimeline.html
diff --git a/routes/_components/timeline/LoadingFooter.html b/src/routes/_components/timeline/LoadingFooter.html
similarity index 100%
rename from routes/_components/timeline/LoadingFooter.html
rename to src/routes/_components/timeline/LoadingFooter.html
diff --git a/routes/_components/timeline/MoreHeader.html b/src/routes/_components/timeline/MoreHeader.html
similarity index 100%
rename from routes/_components/timeline/MoreHeader.html
rename to src/routes/_components/timeline/MoreHeader.html
diff --git a/routes/_components/timeline/MoreHeaderVirtualWrapper.html b/src/routes/_components/timeline/MoreHeaderVirtualWrapper.html
similarity index 100%
rename from routes/_components/timeline/MoreHeaderVirtualWrapper.html
rename to src/routes/_components/timeline/MoreHeaderVirtualWrapper.html
diff --git a/routes/_components/timeline/NotificationVirtualListItem.html b/src/routes/_components/timeline/NotificationVirtualListItem.html
similarity index 100%
rename from routes/_components/timeline/NotificationVirtualListItem.html
rename to src/routes/_components/timeline/NotificationVirtualListItem.html
diff --git a/routes/_components/timeline/PinnedStatuses.html b/src/routes/_components/timeline/PinnedStatuses.html
similarity index 100%
rename from routes/_components/timeline/PinnedStatuses.html
rename to src/routes/_components/timeline/PinnedStatuses.html
diff --git a/routes/_components/timeline/StatusVirtualListItem.html b/src/routes/_components/timeline/StatusVirtualListItem.html
similarity index 100%
rename from routes/_components/timeline/StatusVirtualListItem.html
rename to src/routes/_components/timeline/StatusVirtualListItem.html
diff --git a/routes/_components/timeline/Timeline.html b/src/routes/_components/timeline/Timeline.html
similarity index 100%
rename from routes/_components/timeline/Timeline.html
rename to src/routes/_components/timeline/Timeline.html
diff --git a/routes/_components/virtualList/VirtualList.html b/src/routes/_components/virtualList/VirtualList.html
similarity index 100%
rename from routes/_components/virtualList/VirtualList.html
rename to src/routes/_components/virtualList/VirtualList.html
diff --git a/routes/_components/virtualList/VirtualListContainer.html b/src/routes/_components/virtualList/VirtualListContainer.html
similarity index 100%
rename from routes/_components/virtualList/VirtualListContainer.html
rename to src/routes/_components/virtualList/VirtualListContainer.html
diff --git a/routes/_components/virtualList/VirtualListFooter.html b/src/routes/_components/virtualList/VirtualListFooter.html
similarity index 100%
rename from routes/_components/virtualList/VirtualListFooter.html
rename to src/routes/_components/virtualList/VirtualListFooter.html
diff --git a/routes/_components/virtualList/VirtualListHeader.html b/src/routes/_components/virtualList/VirtualListHeader.html
similarity index 100%
rename from routes/_components/virtualList/VirtualListHeader.html
rename to src/routes/_components/virtualList/VirtualListHeader.html
diff --git a/routes/_components/virtualList/VirtualListItem.html b/src/routes/_components/virtualList/VirtualListItem.html
similarity index 100%
rename from routes/_components/virtualList/VirtualListItem.html
rename to src/routes/_components/virtualList/VirtualListItem.html
diff --git a/routes/_components/virtualList/VirtualListLazyItem.html b/src/routes/_components/virtualList/VirtualListLazyItem.html
similarity index 100%
rename from routes/_components/virtualList/VirtualListLazyItem.html
rename to src/routes/_components/virtualList/VirtualListLazyItem.html
diff --git a/routes/_components/virtualList/virtualListStore.js b/src/routes/_components/virtualList/virtualListStore.js
similarity index 100%
rename from routes/_components/virtualList/virtualListStore.js
rename to src/routes/_components/virtualList/virtualListStore.js
diff --git a/routes/_database/accounts.js b/src/routes/_database/accounts.js
similarity index 100%
rename from routes/_database/accounts.js
rename to src/routes/_database/accounts.js
diff --git a/routes/_database/cache.js b/src/routes/_database/cache.js
similarity index 100%
rename from routes/_database/cache.js
rename to src/routes/_database/cache.js
diff --git a/routes/_database/cleanup.js b/src/routes/_database/cleanup.js
similarity index 100%
rename from routes/_database/cleanup.js
rename to src/routes/_database/cleanup.js
diff --git a/routes/_database/clear.js b/src/routes/_database/clear.js
similarity index 100%
rename from routes/_database/clear.js
rename to src/routes/_database/clear.js
diff --git a/routes/_database/constants.js b/src/routes/_database/constants.js
similarity index 100%
rename from routes/_database/constants.js
rename to src/routes/_database/constants.js
diff --git a/routes/_database/database.js b/src/routes/_database/database.js
similarity index 100%
rename from routes/_database/database.js
rename to src/routes/_database/database.js
diff --git a/routes/_database/databaseApis.js b/src/routes/_database/databaseApis.js
similarity index 100%
rename from routes/_database/databaseApis.js
rename to src/routes/_database/databaseApis.js
diff --git a/routes/_database/databaseLifecycle.js b/src/routes/_database/databaseLifecycle.js
similarity index 100%
rename from routes/_database/databaseLifecycle.js
rename to src/routes/_database/databaseLifecycle.js
diff --git a/routes/_database/helpers.js b/src/routes/_database/helpers.js
similarity index 100%
rename from routes/_database/helpers.js
rename to src/routes/_database/helpers.js
diff --git a/routes/_database/keys.js b/src/routes/_database/keys.js
similarity index 100%
rename from routes/_database/keys.js
rename to src/routes/_database/keys.js
diff --git a/routes/_database/knownInstances.js b/src/routes/_database/knownInstances.js
similarity index 100%
rename from routes/_database/knownInstances.js
rename to src/routes/_database/knownInstances.js
diff --git a/routes/_database/meta.js b/src/routes/_database/meta.js
similarity index 100%
rename from routes/_database/meta.js
rename to src/routes/_database/meta.js
diff --git a/routes/_database/relationships.js b/src/routes/_database/relationships.js
similarity index 100%
rename from routes/_database/relationships.js
rename to src/routes/_database/relationships.js
diff --git a/routes/_database/timelines/cacheStatus.js b/src/routes/_database/timelines/cacheStatus.js
similarity index 100%
rename from routes/_database/timelines/cacheStatus.js
rename to src/routes/_database/timelines/cacheStatus.js
diff --git a/routes/_database/timelines/deletion.js b/src/routes/_database/timelines/deletion.js
similarity index 100%
rename from routes/_database/timelines/deletion.js
rename to src/routes/_database/timelines/deletion.js
diff --git a/routes/_database/timelines/fetchAccount.js b/src/routes/_database/timelines/fetchAccount.js
similarity index 100%
rename from routes/_database/timelines/fetchAccount.js
rename to src/routes/_database/timelines/fetchAccount.js
diff --git a/routes/_database/timelines/fetchNotification.js b/src/routes/_database/timelines/fetchNotification.js
similarity index 100%
rename from routes/_database/timelines/fetchNotification.js
rename to src/routes/_database/timelines/fetchNotification.js
diff --git a/routes/_database/timelines/fetchStatus.js b/src/routes/_database/timelines/fetchStatus.js
similarity index 100%
rename from routes/_database/timelines/fetchStatus.js
rename to src/routes/_database/timelines/fetchStatus.js
diff --git a/routes/_database/timelines/getStatusOrNotification.js b/src/routes/_database/timelines/getStatusOrNotification.js
similarity index 100%
rename from routes/_database/timelines/getStatusOrNotification.js
rename to src/routes/_database/timelines/getStatusOrNotification.js
diff --git a/routes/_database/timelines/insertion.js b/src/routes/_database/timelines/insertion.js
similarity index 100%
rename from routes/_database/timelines/insertion.js
rename to src/routes/_database/timelines/insertion.js
diff --git a/routes/_database/timelines/lookup.js b/src/routes/_database/timelines/lookup.js
similarity index 100%
rename from routes/_database/timelines/lookup.js
rename to src/routes/_database/timelines/lookup.js
diff --git a/routes/_database/timelines/pagination.js b/src/routes/_database/timelines/pagination.js
similarity index 100%
rename from routes/_database/timelines/pagination.js
rename to src/routes/_database/timelines/pagination.js
diff --git a/routes/_database/timelines/pinnedStatuses.js b/src/routes/_database/timelines/pinnedStatuses.js
similarity index 100%
rename from routes/_database/timelines/pinnedStatuses.js
rename to src/routes/_database/timelines/pinnedStatuses.js
diff --git a/routes/_database/timelines/updateStatus.js b/src/routes/_database/timelines/updateStatus.js
similarity index 100%
rename from routes/_database/timelines/updateStatus.js
rename to src/routes/_database/timelines/updateStatus.js
diff --git a/routes/_database/utils.js b/src/routes/_database/utils.js
similarity index 100%
rename from routes/_database/utils.js
rename to src/routes/_database/utils.js
diff --git a/src/routes/_error.html b/src/routes/_error.html
new file mode 100644
index 00000000..7e77a453
--- /dev/null
+++ b/src/routes/_error.html
@@ -0,0 +1,35 @@
+
+ {status}
+
+
+
+
{status}
+
+
{error.message}
+
+
diff --git a/routes/_intl/formatTimeagoDate.js b/src/routes/_intl/formatTimeagoDate.js
similarity index 100%
rename from routes/_intl/formatTimeagoDate.js
rename to src/routes/_intl/formatTimeagoDate.js
diff --git a/src/routes/_layout.html b/src/routes/_layout.html
new file mode 100644
index 00000000..b55b00e6
--- /dev/null
+++ b/src/routes/_layout.html
@@ -0,0 +1,45 @@
+
+
+
+
+
diff --git a/routes/_pages/accounts/[accountId]/followers.html b/src/routes/_pages/accounts/[accountId]/followers.html
similarity index 100%
rename from routes/_pages/accounts/[accountId]/followers.html
rename to src/routes/_pages/accounts/[accountId]/followers.html
diff --git a/routes/_pages/accounts/[accountId]/follows.html b/src/routes/_pages/accounts/[accountId]/follows.html
similarity index 100%
rename from routes/_pages/accounts/[accountId]/follows.html
rename to src/routes/_pages/accounts/[accountId]/follows.html
diff --git a/routes/_pages/accounts/[accountId].html b/src/routes/_pages/accounts/[accountId]/index.html
similarity index 74%
rename from routes/_pages/accounts/[accountId].html
rename to src/routes/_pages/accounts/[accountId]/index.html
index 8893d7d1..747ecf5c 100644
--- a/routes/_pages/accounts/[accountId].html
+++ b/src/routes/_pages/accounts/[accountId]/index.html
@@ -19,14 +19,14 @@
{/if}
\ No newline at end of file
+
diff --git a/routes/_pages/blocked.html b/src/routes/_pages/blocked.html
similarity index 72%
rename from routes/_pages/blocked.html
rename to src/routes/_pages/blocked.html
index 2b444d7d..09fa350b 100644
--- a/routes/_pages/blocked.html
+++ b/src/routes/_pages/blocked.html
@@ -1,10 +1,10 @@
\ No newline at end of file
+
diff --git a/routes/_pages/federated.html b/src/routes/_pages/federated.html
similarity index 63%
rename from routes/_pages/federated.html
rename to src/routes/_pages/federated.html
index 754d0efa..017ae96d 100644
--- a/routes/_pages/federated.html
+++ b/src/routes/_pages/federated.html
@@ -14,11 +14,11 @@
{/if}
\ No newline at end of file
+
diff --git a/routes/_pages/index.html b/src/routes/_pages/index.html
similarity index 68%
rename from routes/_pages/index.html
rename to src/routes/_pages/index.html
index b3b4cb65..60d91e9a 100644
--- a/routes/_pages/index.html
+++ b/src/routes/_pages/index.html
@@ -4,8 +4,8 @@
{/if}
\ No newline at end of file
+
diff --git a/routes/_pages/lists/[listId].html b/src/routes/_pages/lists/[listId].html
similarity index 100%
rename from routes/_pages/lists/[listId].html
rename to src/routes/_pages/lists/[listId].html
diff --git a/routes/_pages/local.html b/src/routes/_pages/local.html
similarity index 62%
rename from routes/_pages/local.html
rename to src/routes/_pages/local.html
index 29498750..a7e67430 100644
--- a/routes/_pages/local.html
+++ b/src/routes/_pages/local.html
@@ -14,11 +14,11 @@
{/if}
\ No newline at end of file
+
diff --git a/routes/_pages/muted.html b/src/routes/_pages/muted.html
similarity index 72%
rename from routes/_pages/muted.html
rename to src/routes/_pages/muted.html
index 46798898..c11c82cc 100644
--- a/routes/_pages/muted.html
+++ b/src/routes/_pages/muted.html
@@ -1,10 +1,10 @@
\ No newline at end of file
+
diff --git a/routes/_pages/pinned.html b/src/routes/_pages/pinned.html
similarity index 75%
rename from routes/_pages/pinned.html
rename to src/routes/_pages/pinned.html
index 580c3f6e..dc6ee67c 100644
--- a/routes/_pages/pinned.html
+++ b/src/routes/_pages/pinned.html
@@ -28,13 +28,13 @@
}
\ No newline at end of file
+
diff --git a/routes/_pages/requests.html b/src/routes/_pages/requests.html
similarity index 82%
rename from routes/_pages/requests.html
rename to src/routes/_pages/requests.html
index eb14e253..988e7db0 100644
--- a/routes/_pages/requests.html
+++ b/src/routes/_pages/requests.html
@@ -1,10 +1,10 @@
\ No newline at end of file
+
diff --git a/routes/_pages/search.html b/src/routes/_pages/search.html
similarity index 68%
rename from routes/_pages/search.html
rename to src/routes/_pages/search.html
index e2a36e00..0a5e0fe6 100644
--- a/routes/_pages/search.html
+++ b/src/routes/_pages/search.html
@@ -23,10 +23,10 @@
}
\ No newline at end of file
+
diff --git a/routes/_pages/settings/about.html b/src/routes/_pages/settings/about.html
similarity index 94%
rename from routes/_pages/settings/about.html
rename to src/routes/_pages/settings/about.html
index de9a2252..39eaf27a 100644
--- a/routes/_pages/settings/about.html
+++ b/src/routes/_pages/settings/about.html
@@ -17,7 +17,7 @@
import SettingsLayout from '../../_components/settings/SettingsLayout.html'
import ExternalLink from '../../_components/ExternalLink.html'
- import { version } from '../../../package.json'
+ import { version } from '../../../../package.json'
export default {
components: {
@@ -28,4 +28,4 @@
version
})
}
-
\ No newline at end of file
+
diff --git a/routes/_pages/settings/general.html b/src/routes/_pages/settings/general.html
similarity index 100%
rename from routes/_pages/settings/general.html
rename to src/routes/_pages/settings/general.html
diff --git a/routes/_pages/settings/index.html b/src/routes/_pages/settings/index.html
similarity index 100%
rename from routes/_pages/settings/index.html
rename to src/routes/_pages/settings/index.html
diff --git a/routes/_pages/settings/instances/[instanceName].html b/src/routes/_pages/settings/instances/[instanceName].html
similarity index 100%
rename from routes/_pages/settings/instances/[instanceName].html
rename to src/routes/_pages/settings/instances/[instanceName].html
diff --git a/routes/_pages/settings/instances/add.html b/src/routes/_pages/settings/instances/add.html
similarity index 100%
rename from routes/_pages/settings/instances/add.html
rename to src/routes/_pages/settings/instances/add.html
diff --git a/routes/_pages/settings/instances/index.html b/src/routes/_pages/settings/instances/index.html
similarity index 100%
rename from routes/_pages/settings/instances/index.html
rename to src/routes/_pages/settings/instances/index.html
diff --git a/routes/_pages/statuses/[statusId]/favorites.html b/src/routes/_pages/statuses/[statusId]/favorites.html
similarity index 100%
rename from routes/_pages/statuses/[statusId]/favorites.html
rename to src/routes/_pages/statuses/[statusId]/favorites.html
diff --git a/routes/_pages/statuses/[statusId]/index.html b/src/routes/_pages/statuses/[statusId]/index.html
similarity index 100%
rename from routes/_pages/statuses/[statusId]/index.html
rename to src/routes/_pages/statuses/[statusId]/index.html
diff --git a/routes/_pages/statuses/[statusId]/reblogs.html b/src/routes/_pages/statuses/[statusId]/reblogs.html
similarity index 100%
rename from routes/_pages/statuses/[statusId]/reblogs.html
rename to src/routes/_pages/statuses/[statusId]/reblogs.html
diff --git a/routes/_pages/tags/[tagName].html b/src/routes/_pages/tags/[tagName].html
similarity index 100%
rename from routes/_pages/tags/[tagName].html
rename to src/routes/_pages/tags/[tagName].html
diff --git a/routes/_static/animations.js b/src/routes/_static/animations.js
similarity index 100%
rename from routes/_static/animations.js
rename to src/routes/_static/animations.js
diff --git a/routes/_static/media.js b/src/routes/_static/media.js
similarity index 100%
rename from routes/_static/media.js
rename to src/routes/_static/media.js
diff --git a/routes/_static/statuses.js b/src/routes/_static/statuses.js
similarity index 100%
rename from routes/_static/statuses.js
rename to src/routes/_static/statuses.js
diff --git a/routes/_static/themes.js b/src/routes/_static/themes.js
similarity index 100%
rename from routes/_static/themes.js
rename to src/routes/_static/themes.js
diff --git a/routes/_static/timelines.js b/src/routes/_static/timelines.js
similarity index 100%
rename from routes/_static/timelines.js
rename to src/routes/_static/timelines.js
diff --git a/routes/_store/LocalStorageStore.js b/src/routes/_store/LocalStorageStore.js
similarity index 100%
rename from routes/_store/LocalStorageStore.js
rename to src/routes/_store/LocalStorageStore.js
diff --git a/routes/_store/computations/autosuggestComputations.js b/src/routes/_store/computations/autosuggestComputations.js
similarity index 100%
rename from routes/_store/computations/autosuggestComputations.js
rename to src/routes/_store/computations/autosuggestComputations.js
diff --git a/routes/_store/computations/computations.js b/src/routes/_store/computations/computations.js
similarity index 100%
rename from routes/_store/computations/computations.js
rename to src/routes/_store/computations/computations.js
diff --git a/routes/_store/computations/instanceComputations.js b/src/routes/_store/computations/instanceComputations.js
similarity index 100%
rename from routes/_store/computations/instanceComputations.js
rename to src/routes/_store/computations/instanceComputations.js
diff --git a/routes/_store/computations/navComputations.js b/src/routes/_store/computations/navComputations.js
similarity index 100%
rename from routes/_store/computations/navComputations.js
rename to src/routes/_store/computations/navComputations.js
diff --git a/routes/_store/computations/timelineComputations.js b/src/routes/_store/computations/timelineComputations.js
similarity index 100%
rename from routes/_store/computations/timelineComputations.js
rename to src/routes/_store/computations/timelineComputations.js
diff --git a/routes/_store/mixins/autosuggestMixins.js b/src/routes/_store/mixins/autosuggestMixins.js
similarity index 100%
rename from routes/_store/mixins/autosuggestMixins.js
rename to src/routes/_store/mixins/autosuggestMixins.js
diff --git a/routes/_store/mixins/instanceMixins.js b/src/routes/_store/mixins/instanceMixins.js
similarity index 100%
rename from routes/_store/mixins/instanceMixins.js
rename to src/routes/_store/mixins/instanceMixins.js
diff --git a/routes/_store/mixins/mixins.js b/src/routes/_store/mixins/mixins.js
similarity index 100%
rename from routes/_store/mixins/mixins.js
rename to src/routes/_store/mixins/mixins.js
diff --git a/routes/_store/mixins/statusMixins.js b/src/routes/_store/mixins/statusMixins.js
similarity index 100%
rename from routes/_store/mixins/statusMixins.js
rename to src/routes/_store/mixins/statusMixins.js
diff --git a/routes/_store/mixins/timelineMixins.js b/src/routes/_store/mixins/timelineMixins.js
similarity index 100%
rename from routes/_store/mixins/timelineMixins.js
rename to src/routes/_store/mixins/timelineMixins.js
diff --git a/routes/_store/observers/autosuggestObservers.js b/src/routes/_store/observers/autosuggestObservers.js
similarity index 100%
rename from routes/_store/observers/autosuggestObservers.js
rename to src/routes/_store/observers/autosuggestObservers.js
diff --git a/routes/_store/observers/customScrollbarObservers.js b/src/routes/_store/observers/customScrollbarObservers.js
similarity index 100%
rename from routes/_store/observers/customScrollbarObservers.js
rename to src/routes/_store/observers/customScrollbarObservers.js
diff --git a/routes/_store/observers/instanceObservers.js b/src/routes/_store/observers/instanceObservers.js
similarity index 100%
rename from routes/_store/observers/instanceObservers.js
rename to src/routes/_store/observers/instanceObservers.js
diff --git a/routes/_store/observers/navObservers.js b/src/routes/_store/observers/navObservers.js
similarity index 100%
rename from routes/_store/observers/navObservers.js
rename to src/routes/_store/observers/navObservers.js
diff --git a/routes/_store/observers/notificationObservers.js b/src/routes/_store/observers/notificationObservers.js
similarity index 100%
rename from routes/_store/observers/notificationObservers.js
rename to src/routes/_store/observers/notificationObservers.js
diff --git a/routes/_store/observers/notificationPermissionObservers.js b/src/routes/_store/observers/notificationPermissionObservers.js
similarity index 100%
rename from routes/_store/observers/notificationPermissionObservers.js
rename to src/routes/_store/observers/notificationPermissionObservers.js
diff --git a/routes/_store/observers/observers.js b/src/routes/_store/observers/observers.js
similarity index 100%
rename from routes/_store/observers/observers.js
rename to src/routes/_store/observers/observers.js
diff --git a/routes/_store/observers/onlineObservers.js b/src/routes/_store/observers/onlineObservers.js
similarity index 100%
rename from routes/_store/observers/onlineObservers.js
rename to src/routes/_store/observers/onlineObservers.js
diff --git a/routes/_store/observers/pageVisibilityObservers.js b/src/routes/_store/observers/pageVisibilityObservers.js
similarity index 100%
rename from routes/_store/observers/pageVisibilityObservers.js
rename to src/routes/_store/observers/pageVisibilityObservers.js
diff --git a/routes/_store/observers/resizeObservers.js b/src/routes/_store/observers/resizeObservers.js
similarity index 100%
rename from routes/_store/observers/resizeObservers.js
rename to src/routes/_store/observers/resizeObservers.js
diff --git a/routes/_store/observers/timelineObservers.js b/src/routes/_store/observers/timelineObservers.js
similarity index 100%
rename from routes/_store/observers/timelineObservers.js
rename to src/routes/_store/observers/timelineObservers.js
diff --git a/routes/_store/store.js b/src/routes/_store/store.js
similarity index 100%
rename from routes/_store/store.js
rename to src/routes/_store/store.js
diff --git a/routes/_thirdparty/a11y-dialog/LICENSE b/src/routes/_thirdparty/a11y-dialog/LICENSE
similarity index 100%
rename from routes/_thirdparty/a11y-dialog/LICENSE
rename to src/routes/_thirdparty/a11y-dialog/LICENSE
diff --git a/routes/_thirdparty/a11y-dialog/a11y-dialog.js b/src/routes/_thirdparty/a11y-dialog/a11y-dialog.js
similarity index 100%
rename from routes/_thirdparty/a11y-dialog/a11y-dialog.js
rename to src/routes/_thirdparty/a11y-dialog/a11y-dialog.js
diff --git a/routes/_thirdparty/autosize/LICENSE.md b/src/routes/_thirdparty/autosize/LICENSE.md
similarity index 100%
rename from routes/_thirdparty/autosize/LICENSE.md
rename to src/routes/_thirdparty/autosize/LICENSE.md
diff --git a/routes/_thirdparty/autosize/autosize.js b/src/routes/_thirdparty/autosize/autosize.js
similarity index 100%
rename from routes/_thirdparty/autosize/autosize.js
rename to src/routes/_thirdparty/autosize/autosize.js
diff --git a/routes/_thirdparty/timeago/LICENSE b/src/routes/_thirdparty/timeago/LICENSE
similarity index 100%
rename from routes/_thirdparty/timeago/LICENSE
rename to src/routes/_thirdparty/timeago/LICENSE
diff --git a/routes/_thirdparty/timeago/timeago.js b/src/routes/_thirdparty/timeago/timeago.js
similarity index 100%
rename from routes/_thirdparty/timeago/timeago.js
rename to src/routes/_thirdparty/timeago/timeago.js
diff --git a/routes/_utils/RealmStore.js b/src/routes/_utils/RealmStore.js
similarity index 100%
rename from routes/_utils/RealmStore.js
rename to src/routes/_utils/RealmStore.js
diff --git a/routes/_utils/ajax.js b/src/routes/_utils/ajax.js
similarity index 100%
rename from routes/_utils/ajax.js
rename to src/routes/_utils/ajax.js
diff --git a/routes/_utils/arrays.js b/src/routes/_utils/arrays.js
similarity index 100%
rename from routes/_utils/arrays.js
rename to src/routes/_utils/arrays.js
diff --git a/routes/_utils/asyncModules.js b/src/routes/_utils/asyncModules.js
similarity index 100%
rename from routes/_utils/asyncModules.js
rename to src/routes/_utils/asyncModules.js
diff --git a/routes/_utils/base64.js b/src/routes/_utils/base64.js
similarity index 100%
rename from routes/_utils/base64.js
rename to src/routes/_utils/base64.js
diff --git a/routes/_utils/checkDomAncestors.js b/src/routes/_utils/checkDomAncestors.js
similarity index 100%
rename from routes/_utils/checkDomAncestors.js
rename to src/routes/_utils/checkDomAncestors.js
diff --git a/routes/_utils/classname.js b/src/routes/_utils/classname.js
similarity index 100%
rename from routes/_utils/classname.js
rename to src/routes/_utils/classname.js
diff --git a/routes/_utils/coordsToPercent.js b/src/routes/_utils/coordsToPercent.js
similarity index 100%
rename from routes/_utils/coordsToPercent.js
rename to src/routes/_utils/coordsToPercent.js
diff --git a/routes/_utils/decodeImage.js b/src/routes/_utils/decodeImage.js
similarity index 100%
rename from routes/_utils/decodeImage.js
rename to src/routes/_utils/decodeImage.js
diff --git a/routes/_utils/delegate.js b/src/routes/_utils/delegate.js
similarity index 100%
rename from routes/_utils/delegate.js
rename to src/routes/_utils/delegate.js
diff --git a/routes/_utils/doubleRAF.js b/src/routes/_utils/doubleRAF.js
similarity index 100%
rename from routes/_utils/doubleRAF.js
rename to src/routes/_utils/doubleRAF.js
diff --git a/routes/_utils/emojiRegex.js b/src/routes/_utils/emojiRegex.js
similarity index 100%
rename from routes/_utils/emojiRegex.js
rename to src/routes/_utils/emojiRegex.js
diff --git a/routes/_utils/emojifyText.js b/src/routes/_utils/emojifyText.js
similarity index 100%
rename from routes/_utils/emojifyText.js
rename to src/routes/_utils/emojifyText.js
diff --git a/routes/_utils/eventBus.js b/src/routes/_utils/eventBus.js
similarity index 100%
rename from routes/_utils/eventBus.js
rename to src/routes/_utils/eventBus.js
diff --git a/routes/_utils/events.js b/src/routes/_utils/events.js
similarity index 100%
rename from routes/_utils/events.js
rename to src/routes/_utils/events.js
diff --git a/routes/_utils/formatters.js b/src/routes/_utils/formatters.js
similarity index 100%
rename from routes/_utils/formatters.js
rename to src/routes/_utils/formatters.js
diff --git a/routes/_utils/fullscreen.js b/src/routes/_utils/fullscreen.js
similarity index 100%
rename from routes/_utils/fullscreen.js
rename to src/routes/_utils/fullscreen.js
diff --git a/routes/_utils/getMainTopMargin.js b/src/routes/_utils/getMainTopMargin.js
similarity index 100%
rename from routes/_utils/getMainTopMargin.js
rename to src/routes/_utils/getMainTopMargin.js
diff --git a/routes/_utils/handleRegex.js b/src/routes/_utils/handleRegex.js
similarity index 100%
rename from routes/_utils/handleRegex.js
rename to src/routes/_utils/handleRegex.js
diff --git a/routes/_utils/historyEvents.js b/src/routes/_utils/historyEvents.js
similarity index 100%
rename from routes/_utils/historyEvents.js
rename to src/routes/_utils/historyEvents.js
diff --git a/routes/_utils/htmlToPlainText.js b/src/routes/_utils/htmlToPlainText.js
similarity index 100%
rename from routes/_utils/htmlToPlainText.js
rename to src/routes/_utils/htmlToPlainText.js
diff --git a/routes/_utils/isMobile.js b/src/routes/_utils/isMobile.js
similarity index 100%
rename from routes/_utils/isMobile.js
rename to src/routes/_utils/isMobile.js
diff --git a/routes/_utils/loadPolyfills.js b/src/routes/_utils/loadPolyfills.js
similarity index 100%
rename from routes/_utils/loadPolyfills.js
rename to src/routes/_utils/loadPolyfills.js
diff --git a/routes/_utils/loadingMask.js b/src/routes/_utils/loadingMask.js
similarity index 100%
rename from routes/_utils/loadingMask.js
rename to src/routes/_utils/loadingMask.js
diff --git a/routes/_utils/marks.js b/src/routes/_utils/marks.js
similarity index 100%
rename from routes/_utils/marks.js
rename to src/routes/_utils/marks.js
diff --git a/routes/_utils/massageUserText.js b/src/routes/_utils/massageUserText.js
similarity index 100%
rename from routes/_utils/massageUserText.js
rename to src/routes/_utils/massageUserText.js
diff --git a/routes/_utils/measureText.js b/src/routes/_utils/measureText.js
similarity index 100%
rename from routes/_utils/measureText.js
rename to src/routes/_utils/measureText.js
diff --git a/routes/_utils/once.js b/src/routes/_utils/once.js
similarity index 100%
rename from routes/_utils/once.js
rename to src/routes/_utils/once.js
diff --git a/routes/_utils/removeEmoji.js b/src/routes/_utils/removeEmoji.js
similarity index 100%
rename from routes/_utils/removeEmoji.js
rename to src/routes/_utils/removeEmoji.js
diff --git a/routes/_utils/replaceEmoji.js b/src/routes/_utils/replaceEmoji.js
similarity index 100%
rename from routes/_utils/replaceEmoji.js
rename to src/routes/_utils/replaceEmoji.js
diff --git a/routes/_utils/reselect.js b/src/routes/_utils/reselect.js
similarity index 100%
rename from routes/_utils/reselect.js
rename to src/routes/_utils/reselect.js
diff --git a/routes/_utils/resize.js b/src/routes/_utils/resize.js
similarity index 100%
rename from routes/_utils/resize.js
rename to src/routes/_utils/resize.js
diff --git a/routes/_utils/runMediumPriorityTask.js b/src/routes/_utils/runMediumPriorityTask.js
similarity index 100%
rename from routes/_utils/runMediumPriorityTask.js
rename to src/routes/_utils/runMediumPriorityTask.js
diff --git a/routes/_utils/safeLocalStorage.js b/src/routes/_utils/safeLocalStorage.js
similarity index 100%
rename from routes/_utils/safeLocalStorage.js
rename to src/routes/_utils/safeLocalStorage.js
diff --git a/routes/_utils/scheduleIdleTask.js b/src/routes/_utils/scheduleIdleTask.js
similarity index 100%
rename from routes/_utils/scheduleIdleTask.js
rename to src/routes/_utils/scheduleIdleTask.js
diff --git a/routes/_utils/scrollContainer.js b/src/routes/_utils/scrollContainer.js
similarity index 100%
rename from routes/_utils/scrollContainer.js
rename to src/routes/_utils/scrollContainer.js
diff --git a/routes/_utils/serviceWorkerClient.js b/src/routes/_utils/serviceWorkerClient.js
similarity index 100%
rename from routes/_utils/serviceWorkerClient.js
rename to src/routes/_utils/serviceWorkerClient.js
diff --git a/routes/_utils/setFavicon.js b/src/routes/_utils/setFavicon.js
similarity index 100%
rename from routes/_utils/setFavicon.js
rename to src/routes/_utils/setFavicon.js
diff --git a/routes/_utils/smoothScrollToTop.js b/src/routes/_utils/smoothScrollToTop.js
similarity index 100%
rename from routes/_utils/smoothScrollToTop.js
rename to src/routes/_utils/smoothScrollToTop.js
diff --git a/routes/_utils/sorting.js b/src/routes/_utils/sorting.js
similarity index 100%
rename from routes/_utils/sorting.js
rename to src/routes/_utils/sorting.js
diff --git a/routes/_utils/strings.js b/src/routes/_utils/strings.js
similarity index 100%
rename from routes/_utils/strings.js
rename to src/routes/_utils/strings.js
diff --git a/routes/_utils/sync.js b/src/routes/_utils/sync.js
similarity index 100%
rename from routes/_utils/sync.js
rename to src/routes/_utils/sync.js
diff --git a/routes/_utils/testStorage.js b/src/routes/_utils/testStorage.js
similarity index 100%
rename from routes/_utils/testStorage.js
rename to src/routes/_utils/testStorage.js
diff --git a/routes/_utils/themeEngine.js b/src/routes/_utils/themeEngine.js
similarity index 100%
rename from routes/_utils/themeEngine.js
rename to src/routes/_utils/themeEngine.js
diff --git a/routes/_utils/thunk.js b/src/routes/_utils/thunk.js
similarity index 100%
rename from routes/_utils/thunk.js
rename to src/routes/_utils/thunk.js
diff --git a/routes/_utils/toast.js b/src/routes/_utils/toast.js
similarity index 100%
rename from routes/_utils/toast.js
rename to src/routes/_utils/toast.js
diff --git a/routes/_utils/urlRegex.js b/src/routes/_utils/urlRegex.js
similarity index 99%
rename from routes/_utils/urlRegex.js
rename to src/routes/_utils/urlRegex.js
index 288e4332..95777dca 100644
--- a/routes/_utils/urlRegex.js
+++ b/src/routes/_utils/urlRegex.js
@@ -128,7 +128,7 @@ export const urlRegex = (function () {
'beats|bcn|bcg|bbva|bbt|bbc|bayern|bauhaus|basketball|baseball|bargains|barefoot|barclays|' +
'barclaycard|barcelona|bar|bank|band|bananarepublic|banamex|baidu|baby|azure|axa|aws|avianca|' +
'autos|auto|author|auspost|audio|audible|audi|auction|attorney|athleta|associates|asia|asda|arte|' +
- 'art|arpa|army|archi|aramco|arab|aquarelle|apple|app|apartments|aol|anz|anquan|android|analytics|' +
+ 'art|arpa|army|archi|aramco|arab|aquarelle|apple|src|apartments|aol|anz|anquan|android|analytics|' +
'amsterdam|amica|amfam|amex|americanfamily|americanexpress|alstom|alsace|ally|allstate|allfinanz|' +
'alipay|alibaba|alfaromeo|akdn|airtel|airforce|airbus|aigo|aig|agency|agakhan|africa|afl|' +
'afamilycompany|aetna|aero|aeg|adult|ads|adac|actor|active|aco|accountants|accountant|accenture|' +
diff --git a/routes/accounts/[accountId]/followers.html b/src/routes/accounts/[accountId]/followers.html
similarity index 80%
rename from routes/accounts/[accountId]/followers.html
rename to src/routes/accounts/[accountId]/followers.html
index 2f8b3cb1..725c73e2 100644
--- a/routes/accounts/[accountId]/followers.html
+++ b/src/routes/accounts/[accountId]/followers.html
@@ -1,16 +1,15 @@
-
+
-
+
diff --git a/routes/blocked.html b/src/routes/blocked.html
similarity index 77%
rename from routes/blocked.html
rename to src/routes/blocked.html
index 8e0d8ea7..bf8fc122 100644
--- a/routes/blocked.html
+++ b/src/routes/blocked.html
@@ -1,16 +1,15 @@
-
+
-
+
\ No newline at end of file
+
diff --git a/routes/community/index.html b/src/routes/community/index.html
similarity index 76%
rename from routes/community/index.html
rename to src/routes/community/index.html
index c4dd49ee..80b5860d 100644
--- a/routes/community/index.html
+++ b/src/routes/community/index.html
@@ -1,16 +1,15 @@
-
+
-
+
\ No newline at end of file
+
diff --git a/routes/favorites.html b/src/routes/favorites.html
similarity index 76%
rename from routes/favorites.html
rename to src/routes/favorites.html
index d81220ce..a2f27621 100644
--- a/routes/favorites.html
+++ b/src/routes/favorites.html
@@ -1,16 +1,15 @@
-
+
-
+
\ No newline at end of file
+
diff --git a/routes/federated.html b/src/routes/federated.html
similarity index 76%
rename from routes/federated.html
rename to src/routes/federated.html
index efd2d819..a22ce08a 100644
--- a/routes/federated.html
+++ b/src/routes/federated.html
@@ -1,16 +1,15 @@
-
+
-
+
\ No newline at end of file
+
diff --git a/routes/index.html b/src/routes/index.html
similarity index 76%
rename from routes/index.html
rename to src/routes/index.html
index c5b5b251..7603d4af 100644
--- a/routes/index.html
+++ b/src/routes/index.html
@@ -1,16 +1,15 @@
-
+
-
+
\ No newline at end of file
+
diff --git a/routes/lists/[listId].html b/src/routes/lists/[listId].html
similarity index 74%
rename from routes/lists/[listId].html
rename to src/routes/lists/[listId].html
index 28b371c3..3ae49653 100644
--- a/routes/lists/[listId].html
+++ b/src/routes/lists/[listId].html
@@ -1,16 +1,15 @@
-
+
-
+
\ No newline at end of file
+
diff --git a/routes/local.html b/src/routes/local.html
similarity index 76%
rename from routes/local.html
rename to src/routes/local.html
index 31fa3925..351b23f1 100644
--- a/routes/local.html
+++ b/src/routes/local.html
@@ -1,16 +1,15 @@
-
+
-
+
\ No newline at end of file
+
diff --git a/routes/muted.html b/src/routes/muted.html
similarity index 77%
rename from routes/muted.html
rename to src/routes/muted.html
index 45f78f10..ed0cd7e3 100644
--- a/routes/muted.html
+++ b/src/routes/muted.html
@@ -1,16 +1,15 @@
-
+
-
+
\ No newline at end of file
+
diff --git a/routes/notifications.html b/src/routes/notifications.html
similarity index 76%
rename from routes/notifications.html
rename to src/routes/notifications.html
index bed5cd0c..b58f3254 100644
--- a/routes/notifications.html
+++ b/src/routes/notifications.html
@@ -1,16 +1,15 @@
-
+
-
+
\ No newline at end of file
+
diff --git a/routes/pinned.html b/src/routes/pinned.html
similarity index 77%
rename from routes/pinned.html
rename to src/routes/pinned.html
index 268e1a2a..54347a49 100644
--- a/routes/pinned.html
+++ b/src/routes/pinned.html
@@ -1,16 +1,15 @@
-
+
-
+
\ No newline at end of file
+
diff --git a/routes/requests.html b/src/routes/requests.html
similarity index 77%
rename from routes/requests.html
rename to src/routes/requests.html
index c4005883..635728de 100644
--- a/routes/requests.html
+++ b/src/routes/requests.html
@@ -1,16 +1,15 @@
-
+
-
+
\ No newline at end of file
+
diff --git a/routes/search.html b/src/routes/search.html
similarity index 76%
rename from routes/search.html
rename to src/routes/search.html
index f17de71b..627a83d3 100644
--- a/routes/search.html
+++ b/src/routes/search.html
@@ -1,16 +1,15 @@
-
+
-
+
\ No newline at end of file
+
diff --git a/routes/settings/about.html b/src/routes/settings/about.html
similarity index 77%
rename from routes/settings/about.html
rename to src/routes/settings/about.html
index 05248740..6cae45f9 100644
--- a/routes/settings/about.html
+++ b/src/routes/settings/about.html
@@ -1,16 +1,15 @@
-
+
-
+
\ No newline at end of file
+
diff --git a/routes/settings/general.html b/src/routes/settings/general.html
similarity index 78%
rename from routes/settings/general.html
rename to src/routes/settings/general.html
index e75e0993..3ef8512d 100644
--- a/routes/settings/general.html
+++ b/src/routes/settings/general.html
@@ -1,16 +1,15 @@
-
+
-
+
\ No newline at end of file
+
diff --git a/routes/settings/index.html b/src/routes/settings/index.html
similarity index 77%
rename from routes/settings/index.html
rename to src/routes/settings/index.html
index 9cbdaa86..93d52ed4 100644
--- a/routes/settings/index.html
+++ b/src/routes/settings/index.html
@@ -1,16 +1,15 @@
-
+
-
+
\ No newline at end of file
+
diff --git a/routes/settings/instances/[instanceName].html b/src/routes/settings/instances/[instanceName].html
similarity index 79%
rename from routes/settings/instances/[instanceName].html
rename to src/routes/settings/instances/[instanceName].html
index ea9d035a..8fda5606 100644
--- a/routes/settings/instances/[instanceName].html
+++ b/src/routes/settings/instances/[instanceName].html
@@ -1,16 +1,15 @@
-
+
-
+
\ No newline at end of file
+
diff --git a/routes/settings/instances/add.html b/src/routes/settings/instances/add.html
similarity index 78%
rename from routes/settings/instances/add.html
rename to src/routes/settings/instances/add.html
index 376b5e27..ff0a96ce 100644
--- a/routes/settings/instances/add.html
+++ b/src/routes/settings/instances/add.html
@@ -1,16 +1,15 @@
-
+
-
+
\ No newline at end of file
+
diff --git a/routes/settings/instances/index.html b/src/routes/settings/instances/index.html
similarity index 78%
rename from routes/settings/instances/index.html
rename to src/routes/settings/instances/index.html
index ea8b5a32..abd6e7af 100644
--- a/routes/settings/instances/index.html
+++ b/src/routes/settings/instances/index.html
@@ -1,16 +1,15 @@
-
+
-
+
\ No newline at end of file
+
diff --git a/routes/settings/quick-login.html b/src/routes/settings/quick-login.html
similarity index 92%
rename from routes/settings/quick-login.html
rename to src/routes/settings/quick-login.html
index 8670401e..c909b56a 100644
--- a/routes/settings/quick-login.html
+++ b/src/routes/settings/quick-login.html
@@ -1,7 +1,7 @@
\ No newline at end of file
+
diff --git a/routes/statuses/[statusId]/favorites.html b/src/routes/statuses/[statusId]/favorites.html
similarity index 77%
rename from routes/statuses/[statusId]/favorites.html
rename to src/routes/statuses/[statusId]/favorites.html
index 7d717e24..da122901 100644
--- a/routes/statuses/[statusId]/favorites.html
+++ b/src/routes/statuses/[statusId]/favorites.html
@@ -1,16 +1,15 @@
-
+
-
+
\ No newline at end of file
+
diff --git a/routes/statuses/[statusId]/index.html b/src/routes/statuses/[statusId]/index.html
similarity index 77%
rename from routes/statuses/[statusId]/index.html
rename to src/routes/statuses/[statusId]/index.html
index 172e94ef..2af4e03a 100644
--- a/routes/statuses/[statusId]/index.html
+++ b/src/routes/statuses/[statusId]/index.html
@@ -1,16 +1,15 @@
-
+
-
+
\ No newline at end of file
+
diff --git a/routes/statuses/[statusId]/reblogs.html b/src/routes/statuses/[statusId]/reblogs.html
similarity index 77%
rename from routes/statuses/[statusId]/reblogs.html
rename to src/routes/statuses/[statusId]/reblogs.html
index cae3729a..5d6fb561 100644
--- a/routes/statuses/[statusId]/reblogs.html
+++ b/src/routes/statuses/[statusId]/reblogs.html
@@ -1,16 +1,15 @@
-
+
-
+
\ No newline at end of file
+
diff --git a/routes/tags/[tagName].html b/src/routes/tags/[tagName].html
similarity index 77%
rename from routes/tags/[tagName].html
rename to src/routes/tags/[tagName].html
index 10002dbf..2c7cd2e8 100644
--- a/routes/tags/[tagName].html
+++ b/src/routes/tags/[tagName].html
@@ -1,16 +1,15 @@
-
+
-
+
\ No newline at end of file
+
diff --git a/server.js b/src/server.js
similarity index 74%
rename from server.js
rename to src/server.js
index f3c04bea..c8bed2a0 100644
--- a/server.js
+++ b/src/server.js
@@ -1,11 +1,12 @@
+import * as sapper from '../__sapper__/server.js'
const express = require('express')
const compression = require('compression')
-const sapper = require('sapper')
const serveStatic = require('serve-static')
const app = express()
const helmet = require('helmet')
+const uuidv4 = require('uuid/v4')
-const headScriptChecksum = require('./inline-script-checksum').checksum
+const headScriptChecksum = require('../inline-script-checksum').checksum
const { PORT = 4002 } = process.env
@@ -30,12 +31,21 @@ const nonDebugOnly = (fn) => (req, res, next) => (
app.use(compression({ threshold: 0 }))
+app.use((req, res, next) => {
+ res.locals.nonce = uuidv4()
+ next()
+})
+
// report.html needs to have CSP disable because it has inline scripts
app.use(debugOnly(helmet()))
app.use(nonDebugOnly(helmet({
contentSecurityPolicy: {
directives: {
- scriptSrc: [`'self'`, `'sha256-${headScriptChecksum}'`],
+ scriptSrc: [
+ `'self'`,
+ `'sha256-${headScriptChecksum}'`,
+ (req, res) => `'nonce-${res.locals.nonce}'`
+ ],
workerSrc: [`'self'`],
styleSrc: [`'self'`, `'unsafe-inline'`],
frameSrc: [`'none'`],
@@ -48,17 +58,17 @@ app.use(nonDebugOnly(helmet({
}
})))
-app.use(serveStatic('assets', {
+app.use(serveStatic('static', {
setHeaders: (res) => {
res.setHeader('Cache-Control', 'public,max-age=600')
}
}))
debugPaths.forEach(debugPath => {
- app.use(debugPath, express.static(`.sapper/client${debugPath}`))
+ app.use(debugPath, express.static(`__sapper__/build/client${debugPath}`))
})
-app.use(sapper())
+app.use(sapper.middleware())
app.listen(PORT, () => {
console.log(`listening on port ${PORT}`)
diff --git a/templates/2xx.html b/src/template.html
similarity index 98%
rename from templates/2xx.html
rename to src/template.html
index 1cf36baf..363097e9 100644
--- a/templates/2xx.html
+++ b/src/template.html
@@ -6,6 +6,8 @@
+ %sapper.base%
+
@@ -36,7 +38,7 @@ html{scrollbar-face-color:var(--scrollbar-face-color);scrollbar-track-color:var(
%sapper.styles%
@@ -48,10 +50,10 @@ html{scrollbar-face-color:var(--scrollbar-face-color);scrollbar-track-color:var(
+//# sourceMappingURL=/inline-script.js.map
+ because `templates/client.js` references it -->
diff --git a/templates/service-worker.js b/src/service-worker.js
similarity index 93%
rename from templates/service-worker.js
rename to src/service-worker.js
index b9caeb87..145442d9 100644
--- a/templates/service-worker.js
+++ b/src/service-worker.js
@@ -1,22 +1,26 @@
-const timestamp = '__timestamp__'
+import {
+ assets as __assets__,
+ shell as __shell__,
+ routes as __routes__
+} from '../__sapper__/service-worker.js'
+
+const timestamp = process.env.SAPPER_TIMESTAMP
const ASSETS = `assets_${timestamp}`
const WEBPACK_ASSETS = `webpack_assets_${timestamp}`
-// `assets` is an array of everything in the `assets` directory
+// `static` is an array of everything in the `static` directory
const assets = __assets__
.map(file => file.startsWith('/') ? file : `/${file}`)
.filter(filename => !filename.startsWith('/apple-icon'))
.filter(filename => !filename.endsWith('.map'))
- .concat(['/index.html'])
// `shell` is an array of all the files generated by webpack
// also contains '/index.html' for some reason
const webpackAssets = __shell__
.filter(filename => !filename.endsWith('.map'))
- .filter(filename => filename !== '/index.html')
// `routes` is an array of `{ pattern: RegExp }` objects that
-// match the pages in your app
+// match the pages in your src
const routes = __routes__
self.addEventListener('install', event => {
@@ -41,7 +45,7 @@ self.addEventListener('activate', event => {
}
}
- // for webpack assets, keep the two latest builds because we may need
+ // for webpack static, keep the two latest builds because we may need
// them when the service worker has installed but the page has not
// yet reloaded (e.g. when it gives the toast saying "please reload"
// but then you don't refresh and instead load an async chunk)
@@ -76,15 +80,15 @@ self.addEventListener('fetch', event => {
if (sameOrigin) {
// always serve webpack-generated resources and
- // assets from the cache if possible
+ // static from the cache if possible
let response = await caches.match(req)
if (response) {
return response
}
// for routes, serve the /index.html file from the most recent
// assets cache
if (routes.find(route => route.pattern.test(url.pathname))) {
- let response = await caches.match('/index.html')
+ let response = await caches.match('/service-worker-index.html')
if (response) {
return response
}
@@ -76,15 +80,15 @@ self.addEventListener('fetch', event => {
return response
}
- // for routes, serve the /index.html file from the most recent
- // assets cache
+ // for routes, serve the /service-worker-index.html file from the most recent
+ // static cache
if (routes.find(route => route.pattern.test(url.pathname))) {